Documentation
¶
Overview ¶
templ: version: v0.3.924
templ: version: v0.3.924
templ: version: v0.3.924
templ: version: v0.3.924
templ: version: v0.3.924
templ: version: v0.3.924
templ: version: v0.3.924
templ: version: v0.3.924
templ: version: v0.3.924
templ: version: v0.3.924
templ: version: v0.3.924
templ: version: v0.3.924
Index ¶
- func DefaultPageHeader() component.Headerdeprecated
- func NewChampionSprite(championID int, size component.TextSize) component.Sprite
- func NewExtraMenu() component.Popover
- func NewHomePage() component.Page
- func NewItemSprite(itemID int, size component.TextSize) component.Sprite
- func NewLoadingModal() component.ModalLayout
- func NewPageFooter() component.Component
- func NewSummonerSearchBar() component.Component
- func NewSummonerSpellSprite(summonerID int, size component.TextSize) component.Sprite
- func NewWardSprite(wardID int, size component.TextSize) component.Sprite
- func PageHeader(ctx context.Context) templ.Component
- func RegionPanel() component.PanelWindow
- type CSWidget
- type ChampionWidget
- type GoldWidget
- type ItemInventory
- type KDAWidget
- type MatchDateDurationWidget
- type NameWidget
- type RankDeltaWidget
- type RankTag
- type RankWidget
- type RegionPickerButton
- type RequestProvider
- type RuneExtraInfoContent
- type RuneImage
- type RuneRow
- type RuneWidget
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultPageHeader
deprecated
func NewChampionSprite ¶
func NewExtraMenu ¶
func NewHomePage ¶
func NewItemSprite ¶
Note: size is only for future compatibility, currently not used.
func NewLoadingModal ¶
func NewLoadingModal() component.ModalLayout
NewLoadingModal is a generic modal used when loading data.
func NewPageFooter ¶
NewPageFooter is the default footer for all pages.
func NewSummonerSearchBar ¶
func NewSummonerSpellSprite ¶
Note: size is only for future compatibility, currently not used.
func NewWardSprite ¶
Note: size is only for future compatibility, currently not used.
func RegionPanel ¶
func RegionPanel() component.PanelWindow
Types ¶
type CSWidget ¶
func NewCSWidget ¶
type ChampionWidget ¶
type ChampionWidget struct {
ChampionSprite component.Sprite
// ChampionLevel is the level of the champion at the end of a match.
// Zero values indicate that level is not included in the component.
ChampionLevel int
// SummonerD and SummonerF are summoner spells. Nil values indicate
// that summoner spells is not be included in the component.
SummonerD, SummonerF *component.Sprite
}
ChampionWidget displays a champion icon and summoner spells. Deprecated: not using
func NewLiveChampionWidget ¶
func NewLiveChampionWidget(championID int, summonerIDs [2]int) ChampionWidget
func NewMatchChampionWidget ¶
func NewMatchChampionWidget(championID int, championLevel int, summonerIDs [2]int) ChampionWidget
func NewSimpleChampionWidget ¶
func NewSimpleChampionWidget(championID int) ChampionWidget
type GoldWidget ¶
type GoldWidget struct {
GoldEarned int
GoldEarnedPerMinute int
GoldDeltaCounterpart int
ShowIcon bool
}
GoldWidget shows stats related to gold earned.
type ItemInventory ¶
type ItemInventory struct {
Items [6]component.Tooltip
Ward component.Tooltip
// VisionScore is the the score at the end of the game.
VisionScore int
// ItemHistory shows additional item build order information.
ItemHistory component.Popover
}
ItemInventory displays an inventory of match items.
TODO: rename to ItemWidget.
func NewItemInventory ¶
func NewItemInventory(items [7]int, visionScore int) ItemInventory
type KDAWidget ¶
KDAWidget is a fixed size widget displaying Kills, Deaths, and Assists.
func NewKDAWidget ¶
type MatchDateDurationWidget ¶
func NewMatchDateDurationWidget ¶
func NewMatchDateDurationWidget(date time.Time, duration time.Duration) MatchDateDurationWidget
type NameWidget ¶
type NameWidget struct {
Name, Tag string
RankWidget RankWidget
}
func NewNameWidget ¶
func NewNameWidget(name, tag string, rank *internal.Rank) NameWidget
type RankDeltaWidget ¶
type RankDeltaWidget struct {
// RankWidget is the rank after the match. A nil value means the store
// did not record a rank after the match.
RankChange *RankWidget
// LPChange is the lp change after the match. A nil value indicates the
// lp change is unknown.
LPChange *int
Win bool
}
RankDeltaWidget shows a rank change after a match.
func NewRankDeltaWidget ¶
func NewRankDeltaWidget(before, after *internal.Rank, win bool) RankDeltaWidget
type RankWidget ¶
type RankWidget struct {
// Rank is the summoner's rank at an instance. A nil value indicates
// summoner is unranked.
Rank *internal.Rank
ShowTierName bool
// Size is the height of the widget, following [TextSize]. [TextSizeXS]
// and [TextSizeSM] are supported.
Size component.TextSize
}
RankWidget displays summoner rank.
func NewRankWidget ¶
func NewRankWidget(rank *internal.Rank) RankWidget
type RegionPickerButton ¶
type RequestProvider ¶
type RuneExtraInfoContent ¶
type RuneExtraInfoContent struct {
RuneRow RuneRow
}
type RuneRow ¶
type RuneRow struct {
Keystone component.Tooltip
Primary [3]component.Tooltip
Secondary [2]component.Tooltip
Mini [3]component.Tooltip
}
RuneRow displays all selected match runes as a row.
func NewRuneRow ¶
type RuneWidget ¶
type RuneWidget struct {
Keystone component.Tooltip
Subtree component.Tooltip
MoreInfo component.Popover
}
RuneWidget displays match runes.
func NewRuneWidget ¶
func NewRuneWidget(runes internal.RunePage) RuneWidget